@@ -8,6 +8,7 @@
  */
 include_once "user.php";
 include_once "database.php";
+include_once "http_util.php";
 
 
 $ERROR_MSG;
@@ -50,6 +51,19 @@ SELECT_USER;
 	return $user;
 }
 
+function chk_file_name(&$val){
+	if(!isset($val)){
+		return false;
+	}
+	if(0 == strlen($val)){
+		return false;
+	}
+	if(FALSE === inspect_file_name($val)){
+		return false;
+	}
+	return true;
+}
+
 function chk_param(&$val){
 	if(!isset($val)){
 		return false;
@@ -57,8 +71,8 @@ function chk_param(&$val){
 	if(0 == strlen($val)){
 		return false;
 	}
-	if(!get_magic_quotes_gpc()){
-		$val = addslashes($val);
+	if(FALSE === inspect_base64_param($val)){
+		return false;
 	}
 	return true;
 }
