@@ -30,7 +30,7 @@ if(FALSE === $user){
 
 //--- parameter check start ---
 if(!chk_param($board_name) || !chk_param($dat_name) ||
-	!chk_param($res_number) || !chk_param($record_type)){
+	!chk_param($res_number)){
 	echo ERROR303;
 	exit;
 }
