@@ -14,7 +14,7 @@ if [ ${REMOVE_DIR} ] ; then
 	fi
 	rm -f help_gen gen/print_help.c
 else
-	for d in  obj obj/utils obj/net obj/_2ch obj/ui obj/html obj/usr ; do
+	for d in  obj obj/utils obj/net obj/_2ch obj/ui obj/html obj/usr obj/cloud ; do
 		if ! [ -e ${d} ]; then
 			mkdir ${d}
 		fi
