@@ -21,19 +21,25 @@
 #include "net/nt_cookie.h"
 #include "_2ch/model_2ch.h"
 #include "_2ch/maru_2ch.h"
+#include "_2ch/search_2ch.h"
 
 
 extern char *URL_2CH_BOARDMENU;
 
 
-extern nt_2ch_model_tp app_2ch_modelp;
+extern nt_2ch_model_handle app_2ch_model;
 
 extern BOOL nt_2ch_model_init();
 extern BOOL nt_init_board_menu();
-extern BOOL nt_read_board(nt_2ch_selected_item_tp selectp);
-extern BOOL nt_read_thread(nt_2ch_selected_item_tp selectp);
-extern BOOL nt_write_msg(nt_2ch_selected_item_tp selectp,
-			nt_write_data_tp writep, nt_cookie_tp cookiep, 
+extern BOOL nt_read_board(nt_2ch_selected_item_handle h_select);
+extern BOOL nt_read_thread(nt_2ch_selected_item_handle h_select);
+extern BOOL nt_write_msg(nt_2ch_selected_item_handle h_select,
+			nt_write_data_handle h_write_data, nt_cookie_tp cookiep, 
 			nt_maru_2ch_tp marup);
 
+extern BOOL nt_set_sel_item(nt_2ch_model_handle h_model,
+			nt_2ch_selected_item_handle *h_sel_itemp, 
+			nt_searched_thread_handle h_sel_thread, const wchar_t** errorpp);
+extern int nt_read_board_list(nt_link_tp selitem_list);
+
 #endif /* _2CH_H_ */
