@@ -66,7 +66,7 @@ extern char *MARU_PW;
 #define NT_INTI_DISP_FAVORITE  2
 #define NT_INTI_DISP_HISTORY   3
 
-#define NT_KEY_NONE (-1)
+#define NT_KEY_NONE (0)
 #define NT_KEY_UP 'k'
 #define NT_KEY_DOWN 'j'
 #define NT_KEY_LEFT 'h'
@@ -116,6 +116,7 @@ extern char *MARU_PW;
 #define NT_COMMAND1_HISTORY_2 "h"
 #define NT_COMMAND1_AUTOSCROLL_1 "autoscroll"
 #define NT_COMMAND1_AUTOSCROLL_2 "a"
+#define NT_COMMAND1_TIMER "timer"
 #define NT_COMMAND1_UPLOAD_1 "upload"
 #define NT_COMMAND1_UPLOAD_BOARD1 "board"
 #define NT_COMMAND1_UPLOAD_BOARD2 "b"
@@ -136,6 +137,10 @@ extern char *MARU_PW;
 #define NT_COMMAND1_NG_NAME_1 "ngname"
 #define NT_COMMAND1_NG_NAME_2 "ngnm"
 #define NT_COMMAND1_NG_ID_1 "ngid"
+#define NT_COMMAND1_OPEN_LINK_1 "link"
+#define NT_COMMAND1_OPEN_LINK_2 "l"
+#define NT_COMMAND1_REPLACE_RES_TEXT_1 "replace"
+#define NT_COMMAND1_REPLACE_RES_TEXT_2 "r"
 
 extern int set_option(int argc, char* argv[]);
 
