@@ -19,14 +19,14 @@
 #define _DISP_STRING_H_
 #include <wchar.h>
 
-extern int nt_add_wch(WINDOW *w, wchar_t wc, attr_t attr);
-extern int nt_add_wnch(WINDOW *w, wchar_t wc, 
+extern int nt_add_wch(WINDOW *w, const wchar_t wc, attr_t attr);
+extern int nt_add_wnch(WINDOW *w, const wchar_t wc, 
 				attr_t attr, size_t colmns);
-extern int nt_add_wstr(WINDOW *w, wchar_t *wc, attr_t attr);
-extern int nt_add_wnstr(WINDOW *w, wchar_t *wc, 
+extern int nt_add_wstr(WINDOW *w, const wchar_t *wc, attr_t attr);
+extern int nt_add_wnstr(WINDOW *w, const wchar_t *wc, 
 				attr_t attr, size_t colmns);
 
-extern int nt_get_wc_count_within_colmns(wchar_t *src, size_t colmns);
-extern int nt_get_column_length(const wchar_t *wc);
+extern int nt_get_wc_count_within_colmns(const wchar_t *src, size_t colmns);
+extern int nt_get_column_length(const const wchar_t *wc);
 
 #endif /* _DISP_STRING_H_ */
