@@ -20,5 +20,7 @@
 extern BOOL nt_make_sha1_path(const char *base_path,
 				const char *org_name, char **outbufp);
 extern BOOL nt_mkdir(const char *dir_name);
+extern nt_link_tp nt_read_text_file(const char* path);
+extern BOOL nt_write_text_file(const char* path, nt_link_tp text);
 
 #endif /* _FILE_H_ */
