@@ -28,6 +28,7 @@ typedef int BOOL;
 typedef void (*nt_memfree_fn)(void* ptr);
 typedef int (*nt_compare_fn)(void *lhs, void *rhs);
 typedef int (*nt_compare_n_fn)(int a, int b);
+typedef void* (*nt_memcopy_fn)(void* ptr);
 
 typedef struct tag_nt_link_t *nt_link_tp;
 typedef struct tag_nt_link_t{
@@ -120,7 +121,10 @@ extern nt_link_tp nt_link_next(nt_link_tp link);
 extern int nt_link_num(nt_link_tp linkp);
 extern void* nt_link_get_by_index(nt_link_tp linkp, int index);
 extern void nt_all_link_free(nt_link_tp ptr, nt_memfree_fn free_func);
-extern nt_link_tp nt_link_copy(nt_link_tp src_linkp);
+extern nt_link_tp nt_link_copy(nt_link_tp src_linkp, nt_memcopy_fn copy_func);
+
+extern void* nt_link_strcpy_fnc(void *ptr);
+extern void* nt_link_wcscpy_fnc(void *ptr);
 extern int nt_link_wcscmp_fnc(void *lhs, void *rhs);
 
 typedef struct tag_nt_key_value_t *nt_key_value_tp;
