@@ -42,6 +42,11 @@ static nt_http_header_tp nt_http_init_header(const char *url);
 static void nt_http_free_header(nt_http_header_tp headerp);
 static BOOL nt_http_init_header2(
 		nt_http_header_tp headerp, const char *out_path);
+static int nt_http_post_local(const char *url, const char *post_data,
+		char **out_buf, size_t out_buf_len, 
+		const char *referer, const char *user_agent, 
+		nt_link_tp extend_headers, 
+		nt_cookie_tp cookiep);
 
 BOOL nt_http_post(const char *url, const char *post_data,
 		char *out_buf, size_t out_buf_len, 
@@ -50,8 +55,8 @@ BOOL nt_http_post(const char *url, const char *post_data,
 		nt_cookie_tp cookiep)
 {
 	int result_code;
-	result_code = nt_http_post2(url, post_data,
-		out_buf, out_buf_len, referer, user_agent, 
+	result_code = nt_http_post_local(url, post_data,
+		&out_buf, out_buf_len, referer, user_agent, 
 		extend_headers, cookiep);
 	return (result_code == 200) ? TRUE : FALSE;
 }
@@ -61,6 +66,32 @@ int nt_http_post2(const char *url, const char *post_data,
 		const char *referer, const char *user_agent, 
 		nt_link_tp extend_headers, 
 		nt_cookie_tp cookiep)
+{
+	return nt_http_post_local(url, post_data,
+					&out_buf, out_buf_len, 
+					referer, user_agent, 
+					extend_headers, 
+					cookiep);
+}
+int nt_http_post3(const char *url, const char *post_data,
+		char **out_buf, 
+		const char *referer, const char *user_agent, 
+		nt_link_tp extend_headers, 
+		nt_cookie_tp cookiep)
+{
+	return nt_http_post_local(url, post_data,
+					out_buf, 0, 
+					referer, user_agent, 
+					extend_headers, 
+					cookiep);
+}
+
+#define BUF_LEN_DELTA (1024*4)
+int nt_http_post_local(const char *url, const char *post_data,
+		char **out_buf, size_t out_buf_len, 
+		const char *referer, const char *user_agent, 
+		nt_link_tp extend_headers, 
+		nt_cookie_tp cookiep)
 {
 	nt_socket_tp socketp = NULL;
 	int fd = -1, sockfd = 0;
@@ -75,6 +106,10 @@ int nt_http_post2(const char *url, const char *post_data,
 	char itoa_buf[33];
 	char cookie_data[1024];
 	char *cptr, *p1, *p2, *p3;
+	int len, new_len;
+	char *tmp_buf;
+	BOOL is_realloc_buf;
+	
 
 	result = 0;
 	nt_http_header_tp headerp = nt_http_init_header(url);
@@ -161,8 +196,8 @@ int nt_http_post2(const char *url, const char *post_data,
 			nt_http_free_header(headerp);
 			return result;
 		}
-		memcpy(out_buf, data+nread, data_len-nread);
-		out_buf[data_len - nread] = '\0';
+		memcpy(*out_buf, data+nread, data_len-nread);
+		(*out_buf)[data_len - nread] = '\0';
 	}else{
 		if(headerp->port == -1)
 			headerp->port = 80;
@@ -198,12 +233,24 @@ int nt_http_post2(const char *url, const char *post_data,
 			return result;
 		}
 	}
+	
+	
 	result = responsep->status_code;
 	switch(result){
 	case 200:
 		if(IS_SET_FLAG(headerp,SSL_FLAG)){
 		}else{
-			cptr = out_buf;
+			if(out_buf_len == 0){
+				tmp_buf = malloc(BUF_LEN_DELTA);
+				if(!tmp_buf)
+					goto ERROR_TRAP;
+				*out_buf = tmp_buf;
+				out_buf_len = BUF_LEN_DELTA;
+				is_realloc_buf = TRUE;
+			}else{
+				is_realloc_buf = FALSE;
+			}
+			cptr = *out_buf;
 			do{
 				nread = read(sockfd, data, sizeof(data));
 				switch(nread){
@@ -212,8 +259,19 @@ int nt_http_post2(const char *url, const char *post_data,
 				case 0:
 					break;
 				default:
-					if(out_buf_len <= (cptr - out_buf) + nread){
-						goto ERROR_TRAP;
+					len = cptr - (*out_buf);
+					if(out_buf_len <= len + nread){
+						if(!is_realloc_buf)
+							goto ERROR_TRAP;
+						new_len = ((len + nread) / BUF_LEN_DELTA + 1) * BUF_LEN_DELTA;
+						tmp_buf = malloc(new_len);
+						if(!tmp_buf)
+							goto ERROR_TRAP;
+						memcpy(tmp_buf, *out_buf, len);
+						free(*out_buf);
+						*out_buf = tmp_buf;
+						out_buf_len = new_len;
+						cptr = (*out_buf) + len;
 					}
 					memcpy(cptr, data, nread);
 					cptr[nread] = '\0';
@@ -224,7 +282,7 @@ int nt_http_post2(const char *url, const char *post_data,
 			if(nread > 0){
 				result = 0;
 			}else if(IS_SET_FLAG(responsep, CHUNKED_FLAG)){
-				p3 = p1 = out_buf;
+				p3 = p1 = *out_buf;
 				while(0 < (nread = strtol(p1, &p2, 16))){
 					memmove(p3, p2+2, nread);
 					p3 += nread;
