@@ -184,3 +184,24 @@ BOOL nt_parse_server_name_and_board_name(const wchar_t *url,
 	*board_name = cptr2;
 	return TRUE;
 }
+
+BOOL nt_is_ipv6_addr(const char *addr, char **endp)
+{
+	int len;
+	char *cptr;
+	if(!addr)
+		return FALSE;
+	len = strlen(addr);
+	if(len == 0)
+		return FALSE;
+	if(addr[0] != '[')
+		return FALSE;
+	
+	cptr = strchr(addr+1, ']');
+	if(!cptr)
+		return FALSE;
+	
+	*endp = cptr;
+	return TRUE;
+}
+
