@@ -41,6 +41,7 @@ nt_socket_tp nt_socket_init(int port, char *addr)
 	struct addrinfo *addr_out, *addr_list;
 	struct sockaddr_in  *s_addr;
 	struct sockaddr_in6 *s_addr6;
+	int err;
 	
 #else
 	struct hostent *hostinfo;
@@ -66,7 +67,9 @@ nt_socket_tp nt_socket_init(int port, char *addr)
 	addr_limit.ai_family = AF_UNSPEC;
 	addr_limit.ai_socktype = SOCK_STREAM;
 	addr_limit.ai_protocol = IPPROTO_TCP;
-	if(0 != getaddrinfo(addr, NULL, &addr_limit, &addr_out)){
+	err = getaddrinfo(addr, NULL, &addr_limit, &addr_out);
+	if(0 != err){
+		 fprintf(stderr, "getaddrinfo: %s\n", gai_strerror(err));
 		free(ptr);
 		return NULL;
 	}
