@@ -34,6 +34,8 @@
 #define NT_CMD_ERR -1
 #define NT_CMD_NONE 0
 #define NT_CMD_LIMIT 1
+#define NT_CMD_DISP_FAVORITE 2
+#define NT_CMD_SEARCH_THREAD 3
 
 #define LINE_HEIGHT 2
 
@@ -317,6 +319,9 @@ int disp_history(nt_window_tp wp,
 		}
 		break;
 	case NT_KEY_CLOSE:
+	case NT_KEY_RIGHT:
+		return ctxp->prev_state;
+	case NT_KEY_ERASE:
 	case KEY_LEFT:
 		return DISP_STATE_BOARDMENU;
 	case NT_KEY_REFRESH:
@@ -325,6 +330,10 @@ int disp_history(nt_window_tp wp,
 		assert(wp->cmd_param);
 		cmd = parse_cmd1(wp->cmd_param, &limit, &offset);
 		switch(cmd){
+		case NT_CMD_DISP_FAVORITE:
+			return DISP_STATE_FAVORITE;
+		case NT_CMD_SEARCH_THREAD:
+			return DISP_STATE_SEARCH_THREAD;
 		case NT_CMD_LIMIT:
 			if(limit >= 0)
 				ctxp->query_limit = limit;
@@ -339,8 +348,6 @@ int disp_history(nt_window_tp wp,
 			return (DISP_STATE_RESLIST | DISP_CMD_REENTER);
 		}
 		break;
-	case NT_KEY_RIGHT:
-		return ctxp->prev_state;
 	case NT_KEY_SELECT:
 	case KEY_RIGHT:
 		num = 0;
@@ -401,10 +408,10 @@ int disp_history(nt_window_tp wp,
 		title = disp_datap->title;
 		if(!title)
 			title = L"Unknown Title";
-		swprintf(wbuf, sizeof(wbuf), L"%3d [%ls] %ls (%d)", num + ctxp->query_offset,
+		swprintf(wbuf, sizeof(wbuf)/sizeof(wchar_t), L"%3d [%ls] %ls (%d)", num + ctxp->query_offset,
 				disp_datap->board_name, title, res_count);
 		if(read_count < res_count){
-			swprintf(wbuf2, sizeof(wbuf2), L"未読%d", res_count - read_count);
+			swprintf(wbuf2, sizeof(wbuf2)/sizeof(wchar_t), L"未読%d", res_count - read_count);
 			wcscat(wbuf, wbuf2);
 		}
 		if(row >= ctxp->scroll_pos){
@@ -534,6 +541,12 @@ static int parse_cmd1(const char *param, int *limit, int *offset)
 	
 	if(0 == strncmp(NT_COMMAND1_LIMIT_1, start, len) ||
 			0 == strncmp(NT_COMMAND1_LIMIT_2, start, len)){
+	}else if((0 == strncmp(NT_COMMAND1_FAVORITE_1,param, len)) ||
+			(0 == strncmp(NT_COMMAND1_FAVORITE_2,param, len))){
+		return NT_CMD_DISP_FAVORITE;
+	}else if((0 == strncmp(NT_COMMAND1_SEARCH_1,param, len)) ||
+			(0 == strncmp(NT_COMMAND1_SEARCH_2,param, len))){
+		return NT_CMD_SEARCH_THREAD;
 	}else{
 		return NT_CMD_NONE;
 	}
