@@ -49,6 +49,9 @@
 #define NT_CMD_EDT_NGWORD 12
 #define NT_CMD_EDT_NGNAME 13
 #define NT_CMD_EDT_NGID 14
+#define NT_CMD_OPEN_LINK 15
+#define NT_CMD_REPLACE_RES_TEXT 16
+#define NT_CMD_SET_ALTER 17
 
 #define AUTO_SCROLL_NONE 0
 #define AUTO_SCROLL_UP  -1
@@ -120,8 +123,12 @@ static int get_id_num(ctx_reslist_tp ctxp, const wchar_t *misc);
 static BOOL set_res_header(ctx_reslist_tp ctxp, res_data_tp res_datap,
 				wchar_t *buf, size_t buf_len);
 
-int disp_reslist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle h_select,
-	nt_usr_db_handle usr_db_handle, nt_ng_word_handle h_ng_word, nt_cloud_handle h_cloud)
+int disp_reslist(nt_window_tp wp, int prev_state, 
+		nt_2ch_model_handle h_model, 
+		nt_usr_db_handle usr_db_handle,
+		nt_ng_word_handle h_ng_word, nt_cloud_handle h_cloud,
+		nt_2ch_selected_item_handle h_select, 
+		nt_searched_thread_handle *h_sel_threadp)
 {
 	ctx_reslist_tp ctxp, child_ctxp;
 	res_data_tp res_datap;
@@ -442,6 +449,8 @@ int disp_reslist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle h_
 		switch(cmd){
 		case NT_CMD_AUTO_SCROLL:
 			return DISP_CMD_AUTO_SCROLL | DISP_STATE_RESLIST;
+		case NT_CMD_SET_ALTER:
+			return DISP_CMD_SET_ALERT | DISP_STATE_RESLIST;
 		case NT_CMD_SEARCH_THREAD:
 			return DISP_STATE_SEARCH_THREAD;
 		case NT_CMD_FAVORITE:
@@ -481,6 +490,13 @@ int disp_reslist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle h_
 		case NT_CMD_EDT_NGID:
 			free_disp_lines_ctx(wp->data);
 			return DISP_CMD_EDIT_NGID | DISP_STATE_RESLIST;
+		case NT_CMD_OPEN_LINK:
+			*h_sel_threadp = nt_searched_thread_alloc2(h_model, endp);
+			if(h_sel_threadp)
+				return DISP_CMD_OPEN_2CH_LINK | DISP_STATE_RESLIST;
+			break;
+		case NT_CMD_REPLACE_RES_TEXT:
+			break;
 		default:
 			if(cmd == NT_CMD_TREE){
 				linkp = parse_tree_list((ctx_reslist_tp)wp->data, endp);
@@ -969,6 +985,9 @@ static int parse_cmd1(const char *param, const char **end)
 		0 == strncmp(NT_COMMAND1_AUTOSCROLL_2,param,
 			strlen(NT_COMMAND1_AUTOSCROLL_2))){
 		return NT_CMD_AUTO_SCROLL;
+	}else if(0 == strncmp(NT_COMMAND1_TIMER,param,
+			strlen(NT_COMMAND1_TIMER))){
+		return NT_CMD_SET_ALTER;
 	}else if(0 == strncmp(NT_COMMAND1_NG_WORD_1,param,len) ||
 			0 == strncmp(NT_COMMAND1_NG_WORD_2,param, len)){
 		if(!nt_strtok(*end, ' ', &start, end))
@@ -998,6 +1017,26 @@ static int parse_cmd1(const char *param, const char **end)
 			return NT_CMD_EDT_NGID;
 		*end = start;
 		return NT_CMD_ADD_NGID;
+	}else if(0 == strncmp(NT_COMMAND1_OPEN_LINK_1,param,len) ||
+			0 == strncmp(NT_COMMAND1_OPEN_LINK_2,param, len)){
+		if(!nt_strtok(*end, ' ', &start, end))
+			return NT_CMD_NONE;
+		
+		len = *end - start;
+		if(len <= 0)
+			return NT_CMD_NONE;
+		*end = start;
+		return NT_CMD_OPEN_LINK;
+	}else if(0 == strncmp(NT_COMMAND1_REPLACE_RES_TEXT_1,param,len) ||
+			0 == strncmp(NT_COMMAND1_REPLACE_RES_TEXT_2,param, len)){
+		if(!nt_strtok(*end, ' ', &start, end))
+			return NT_CMD_NONE;
+		
+		len = *end - start;
+		if(len <= 0)
+			return NT_CMD_NONE;
+		*end = start;
+		return NT_CMD_REPLACE_RES_TEXT;
 	}
 	return NT_CMD_NONE;
 }
