@@ -26,6 +26,7 @@
 #include "usr/favorite_t.h"
 #include "usr/usr_db_t.h"
 #include "utils/text.h"
+#include "utils/nt_pthread.h"
 #include "utils/nt_conv_char.h" 
 
 #define NT_FAVORITE_CHK_SUM (678428)
@@ -710,25 +711,29 @@ ERROR_TRAP:
 
 int nt_favorite_add_ref(nt_favorite_handle handle)
 {
+	int c;
 	assert(handle);
 	nt_favorite_tp favoritep;
 	favoritep = (nt_favorite_tp)handle;
 	assert(favoritep->handle.chk_sum == NT_FAVORITE_CHK_SUM);
 	assert(favoritep->ref_count > 0);
-	return ++favoritep->ref_count;
+	c = nt_pthread_increment_int(&favoritep->ref_count);
+	return c;
 }
 
 
 int nt_favorite_release_ref(nt_favorite_handle handle)
 {
+	int c;
 	assert(handle);
 	nt_favorite_tp favoritep;
 	favoritep = (nt_favorite_tp)handle;
 	assert(favoritep->handle.chk_sum == NT_FAVORITE_CHK_SUM);
 	assert(favoritep->ref_count > 0);
-	favoritep->ref_count--;
-	if(0 != favoritep->ref_count)
-		return favoritep->ref_count;
+	c = nt_pthread_decrement_int(&favoritep->ref_count);
+	if(0 != c){
+		return c;
+	}
 
 	
 	if(favoritep->favorite_board_list){
@@ -746,24 +751,28 @@ int nt_favorite_release_ref(nt_favorite_handle handle)
 
 int nt_favorite_board_add_ref(nt_favorite_board_handle handle)
 {
+	int c;
 	assert(handle);
 	nt_favorite_board_tp boardp;
 	boardp = (nt_favorite_board_tp)handle;
 	assert(boardp->handle.chk_sum == NT_FAVORITE_BOARD_CHK_SUM);
 	assert(boardp->ref_count > 0);
-	return ++boardp->ref_count;
+	c = nt_pthread_increment_int(&boardp->ref_count);
+	return c;
 }
 
 int nt_favorite_board_release_ref(nt_favorite_board_handle handle)
 {
+	int c;
 	assert(handle);
 	nt_favorite_board_tp boardp;
 	boardp = (nt_favorite_board_tp)handle;
 	assert(boardp->handle.chk_sum == NT_FAVORITE_BOARD_CHK_SUM);
 	assert(boardp->ref_count > 0);
-	boardp->ref_count--;
-	if(0 != boardp->ref_count)
-		return boardp->ref_count;
+	c = nt_pthread_decrement_int(&boardp->ref_count);
+	if(0 != c){
+		return c;
+	}
 	free(boardp->board_name);
 	free(boardp);
 	return 0;
@@ -771,25 +780,29 @@ int nt_favorite_board_release_ref(nt_favorite_board_handle handle)
 
 int nt_favorite_grp_add_ref(nt_favorite_grp_handle handle)
 {
+	int c;
 	assert(handle);
 	nt_favorite_grp_tp grpp;
 	grpp = (nt_favorite_grp_tp)handle;
 	assert(grpp->handle.chk_sum == NT_FAVORITE_GRP_CHK_SUM);
 	assert(grpp->ref_count > 0);
-	return ++grpp->ref_count;
+	c = nt_pthread_increment_int(&grpp->ref_count);
+	return c;
 }
 
 
 int nt_favorite_grp_release_ref(nt_favorite_grp_handle handle)
 {
+	int c;
 	assert(handle);
 	nt_favorite_grp_tp grpp;
 	grpp = (nt_favorite_grp_tp)handle;
 	assert(grpp->handle.chk_sum == NT_FAVORITE_GRP_CHK_SUM);
 	assert(grpp->ref_count > 0);
-	grpp->ref_count--;
-	if(0 != grpp->ref_count)
-		return grpp->ref_count;
+	c = nt_pthread_decrement_int(&grpp->ref_count);
+	if(0 != c){
+		return c;
+	}
 	assert((grpp->num_content == 0 && !grpp->contents) ||
 			(grpp->num_content > 0 && grpp->contents));
 	if(grpp->contents){
@@ -802,24 +815,28 @@ int nt_favorite_grp_release_ref(nt_favorite_grp_handle handle)
 
 int nt_favorite_thread_add_ref(nt_favorite_thread_handle handle)
 {
+	int c;
 	assert(handle);
 	nt_favorite_thread_tp threadp;
 	threadp = (nt_favorite_thread_tp)handle;
 	assert(threadp->handle.chk_sum == NT_FAVORITE_THREAD_CHK_SUM);
 	assert(threadp->ref_count > 0);
-	return ++threadp->ref_count;
+	c = nt_pthread_increment_int(&threadp->ref_count);
+	return c;
 }
 
 int nt_favorite_thread_release_ref(nt_favorite_thread_handle handle)
 {
+	int c;
 	assert(handle);
 	nt_favorite_thread_tp threadp;
 	threadp = (nt_favorite_thread_tp)handle;
 	assert(threadp->handle.chk_sum == NT_FAVORITE_THREAD_CHK_SUM);
 	assert(threadp->ref_count > 0);
-	threadp->ref_count--;
-	if(0 != threadp->ref_count)
-		return threadp->ref_count;
+	c = nt_pthread_decrement_int(&threadp->ref_count);
+	if(0 != c){
+		return c;
+	}
 	free(threadp->dat_name);
 	free(threadp->board_name);
 	free(threadp->title);
@@ -909,6 +926,11 @@ BOOL nt_favorite_load_boards(nt_favorite_handle handle,
 		return FALSE;
 	}
 	favoritep = (nt_favorite_tp)handle;
+	if(favoritep->favorite_board_list){
+		nt_all_link_free(favoritep->favorite_board_list, 
+				free_favorite_board);
+		favoritep->favorite_board_list = NULL;
+	}
 	linkp = board_list;
 	do{
 		cptr = linkp->data;
@@ -1005,6 +1027,10 @@ BOOL nt_favorite_load_threads(nt_favorite_handle handle,
 	}
 	grpp = (nt_favorite_grp_tp)h_grp;
 	assert(grpp->handle.chk_sum == NT_FAVORITE_GRP_CHK_SUM);
+	if(grpp->contents){
+		nt_all_link_free(grpp->contents, free_grp_content);
+		grpp->contents = NULL;
+	}
 	linkp = thread_list;
 	do{
 		
