@@ -108,7 +108,7 @@ nt_link_tp nt_read_text_file(const char* path)
 	if(!fp)
 		return NULL;
 	
-	while(fgetws(wc, sizeof(wc), fp)){
+	while(fgetws(wc, sizeof(wc)/sizeof(wchar_t)-1, fp)){
 		cptr = nt_w_trim(wc);
 		if(cptr){
 			wrkp = nt_link_add_data(linkp, cptr);
